<?php

namespace Bitrix\Php_interfase;

/**
 * Class InitEventHandler
 *
 * This class handles the initialization of event handlers in Bitrix by requiring necessary files containing event subscriptions and handlers.
 */
class InitEventHandler
{

    /**
     * @var array $pachArray Array of relative file paths to event handler scripts.
     *
     * This static array holds the list of files that contain event handler subscriptions and functions.
     * The paths are relative to the document root of the server.
     */
	static public $pachArray = [
        '/bitrix/modules/sale/handlers/paysystem/paykeeper/eventhandler.php',
	];

    /**
     * Adds the event handlers by including the necessary files.
     *
     * This method iterates through the $pachArray and checks if the file exists in the specified path.
     * If the file exists, it is included into the script using `require_once`.
     *
     * @return void
     */
    static public function add()
    {
    	foreach (self::$pachArray as $pach) {
    		if (file_exists($_SERVER["DOCUMENT_ROOT"].$pach)) {
				require_once $_SERVER["DOCUMENT_ROOT"].$pach;
			}
    	}
    }
}

/**
 * Register the InitEventHandler::add method as an autoloader.
 *
 * The spl_autoload_register function is used to register the static method `add` of the `InitEventHandler` class as an autoloader.
 * When an undefined class is called, this autoloader will be triggered to load the corresponding event handler files.
 */
spl_autoload_register(__NAMESPACE__ . '\InitEventHandler::add');
